.. toctree::
   :maxdepth: 1
   :hidden:

   installation
   usage
   concepts

   API Reference <modules>
   Help Us Improve <contributing>
   Code of Conduct <code-of-conduct>
   Developer Credits <authors>
   Project History <history>

.. include:: ../README.rst

